==> filemanager-0.0.2.0.tar.bz2: content/filemanager.js <==
netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect");
var finishedUrl = Components.classes["@mozilla.org/network/standard-url;1"].createInstance( );
finishedUrl = finishedUrl.QueryInterface(Components.interfaces.nsIURL);
finishedUrl.spec = "chrome://filemanager/locale/mailnotify.wav";

var sound = Components.classes["@mozilla.org/sound;1"].createInstance( );
sound = sound.QueryInterface(Components.interfaces.nsISound);

var progress = 0;

//How many miliseconds the feedback sould remain in the statusbar
const statusbarTimeout = 3000;

function setStatusbar(text) {
  var feedback = document.getElementById('feedback');
  feedback.setAttribute('label', text);
  setTimeout("clearStatusbar()", statusbarTimeout);
}


function clearStatusbar() {
  var feedback = document.getElementById('feedback');
  feedback.setAttribute('label', '');
}


function resetProgress() {
  var progressmeter = document.getElementById('task');
  progressmeter.setAttribute('mode', 'undetermined');
  progress = 0;
}


function startProgress() {
  var progressmeter = document.getElementById('task');
  progressmeter.setAttribute('mode', 'determined');
  showProgress();
}


//Det er ikke s smart hvis funktionen blive kaldt flere gange manuelt
function showProgress() {
  var progressmeter = document.getElementById('task');
  progressmeter.setAttribute('value', progress);
  progress+=1;
  if (progress < 100)
    setTimeout("showProgress()", 100);
  else {
    progressmeter.setAttribute('mode', 'determined');
    progressmeter.setAttribute('value', 100);
    sound.play(finishedUrl);
  }
}

==> filemanager-0.0.2.1.tar.bz2: content/filemanager.js <==
netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect");
var finishedUrl = Components.classes["@mozilla.org/network/standard-url;1"].createInstance( );
finishedUrl = finishedUrl.QueryInterface(Components.interfaces.nsIURL);
finishedUrl.spec = "chrome://filemanager/locale/mailnotify.wav";

var sound = Components.classes["@mozilla.org/sound;1"].createInstance( );
sound = sound.QueryInterface(Components.interfaces.nsISound);

var progress = 0;

//How many miliseconds the feedback sould remain in the statusbar
const statusbarTimeout = 3000;

function setStatusbar(text) {
  var feedback = document.getElementById('feedback');
  feedback.setAttribute('label', text);
  setTimeout("clearStatusbar()", statusbarTimeout);
}


function clearStatusbar() {
  var feedback = document.getElementById('feedback');
  feedback.setAttribute('label', '');
}


function resetProgress() {
  var progressmeter = document.getElementById('task');
  progressmeter.setAttribute('mode', 'undetermined');
  progress = 0;
}


function startProgress() {
  var progressmeter = document.getElementById('task');
  progressmeter.setAttribute('mode', 'determined');
  showProgress();
}


//Det er ikke s smart hvis funktionen blive kaldt flere gange manuelt
function showProgress() {
  var progressmeter = document.getElementById('task');
  progressmeter.setAttribute('value', progress);
  progress+=1;
  if (progress < 100)
    setTimeout("showProgress()", 100);
  else {
    progressmeter.setAttribute('mode', 'determined');
    progressmeter.setAttribute('value', 100);
    sound.play(finishedUrl);
  }
}

/////////////////////////////
/* function displayAboutBox()
{
  var mVersion = getBrowser().mVersion;
  var mVersionRev = getBrowser().mVersionRev;
  window.openDialog("chrome://filemanager/content/filemanagerAbout.xul", "multiviewsClose", 
                    "chrome,dialog,dependent",mVersion+mVersionRev,loadURI);
}*/

function displayAboutBox()
{
  window.openDialog("chrome://filemanager/content/filemanagerAbout.xul", "dunnowhatsthat", 
                    "chrome,dialog,dependent","0.0.2.0");
}
